# QUOTECAST RELATED
CHART = "https://charting.vwdservices.com/hchart/v1/deGiro/data.js?"
QUOTECAST = "https://degiro.quotecast.vwdservices.com/CORS"
QUOTECAST_VERSION = "1.0.20201211"

# TRADING RELATED
ACCOUNT_INFO = "https://trader.degiro.nl/trading/secure/v5/account/info"
ACCOUNT_OVERVIEW = "https://trader.degiro.nl/reporting/secure/v6/accountoverview"
AGENDA = "https://trader.degiro.nl/dgtbxdsservice/agenda/v2"
CASH_ACCOUNT_REPORT = "https://trader.degiro.nl/reporting/secure/v3/cashAccountReport"
CLIENT_DETAILS = "https://trader.degiro.nl/pa/secure/client"
COMPANY_PROFILE = "https://trader.degiro.nl/dgtbxdsservice/company-profile/v2"
COMPANY_RATIOS = "https://trader.degiro.nl/dgtbxdsservice/company-ratios"
CONFIG = "https://trader.degiro.nl/login/secure/config"
ESTIMATES_SUMMARIES = "https://trader.degiro.nl/dgtbxdsservice/estimates-summaries"
FINANCIAL_STATEMENTS = "https://trader.degiro.nl/dgtbxdsservice/financial-statements"
LATEST_NEWS = "https://trader.degiro.nl/dgtbxdsservice/newsfeed/v2/latest-news"
LOGIN = "https://trader.degiro.nl/login/secure/login"
LOGOUT = "https://trader.degiro.nl/trading/secure/logout"
NEWS_BY_COMPANY = "https://trader.degiro.nl/dgtbxdsservice/newsfeed/v2/news-by-company"
ORDER_CHECK = "https://trader.degiro.nl/trading/secure/v5/checkOrder"
ORDER_CONFIRM = "https://trader.degiro.nl/trading/secure/v5/order"
ORDER_DELETE = "https://trader.degiro.nl/trading/secure/v5/order"
ORDERS_HISTORY = "https://trader.degiro.nl/reporting/secure/v4/order-history"
ORDER_UPDATE = "https://trader.degiro.nl/trading/secure/v5/order"
POSITION_REPORT = "https://trader.degiro.nl/reporting/secure/v3/positionReport"
FAVOURITES_LIST = "https://trader.degiro.nl/favorites/secure/v1"
PRODUCT_SEARCH_BONDS = "https://trader.degiro.nl/product_search/secure/v5/bonds"
PRODUCT_SEARCH_ETFS = "https://trader.degiro.nl/product_search/secure/v5/etfs"
PRODUCT_SEARCH_FUNDS = "https://trader.degiro.nl/product_search/secure/v5/funds"
PRODUCT_SEARCH_FUTURES = "https://trader.degiro.nl/product_search/secure/v5/futures"
PRODUCT_SEARCH_LEVERAGEDS = (
    "https://trader.degiro.nl/product_search/secure/v5/leverageds"
)
PRODUCT_SEARCH_LOOKUP = (
    "https://trader.degiro.nl/product_search/secure/v5/products/lookup"
)
PRODUCT_SEARCH_OPTIONS = "https://trader.degiro.nl/product_search/secure/v5/options"
PRODUCT_SEARCH_STOCKS = "https://trader.degiro.nl/product_search/secure/v5/stocks"
PRODUCT_SEARCH_WARRANTS = "https://trader.degiro.nl/product_search/secure/v5/warrants"
PRODUCTS_INFO = "https://trader.degiro.nl/product_search/secure/v5/products/info"
PRODUCTS_CONFIG = "https://trader.degiro.nl/product_search/config/dictionary"
TOP_NEWS_PREVIEW = (
    "https://trader.degiro.nl/dgtbxdsservice/newsfeed/v2/top-news-preview"
)
TRANSACTIONS_HISTORY = "https://trader.degiro.nl/reporting/secure/v4/transactions"
UPDATE = "https://trader.degiro.nl/trading/secure/v5/update"
