# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: degiro_connector/trading/models/trading.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n-degiro_connector/trading/models/trading.proto\x12\x18\x64\x65giro_connector.trading\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\x8b\x01\n\x0b\x43redentials\x12\x13\n\x0bint_account\x18\x01 \x01(\x05\x12\x10\n\x08username\x18\x02 \x01(\t\x12\x10\n\x08password\x18\x03 \x01(\t\x12\x19\n\x0ftotp_secret_key\x18\x04 \x01(\tH\x00\x12\x1b\n\x11one_time_password\x18\x05 \x01(\x05H\x00\x42\x0b\n\toneof_2fa\"\x94\n\n\x05Order\x12\x36\n\x06\x61\x63tion\x18\x01 \x01(\x0e\x32&.degiro_connector.trading.Order.Action\x12\n\n\x02id\x18\x02 \x01(\t\x12=\n\norder_type\x18\x03 \x01(\x0e\x32).degiro_connector.trading.Order.OrderType\x12\r\n\x05price\x18\x04 \x01(\x01\x12\x12\n\nstop_price\x18\x05 \x01(\x01\x12\x12\n\nproduct_id\x18\x06 \x01(\x05\x12\x0c\n\x04size\x18\x07 \x01(\x01\x12;\n\ttime_type\x18\x08 \x01(\x0e\x32(.degiro_connector.trading.Order.TimeType\x12\x15\n\rcontract_size\x18\t \x01(\x01\x12\x15\n\rcontract_type\x18\n \x01(\x05\x12\x10\n\x08\x63urrency\x18\x0b \x01(\t\x12\x0c\n\x04hour\x18\x0c \x01(\t\x12\x14\n\x0cis_deletable\x18\r \x01(\x08\x12\x15\n\ris_modifiable\x18\x0e \x01(\x08\x12\x0f\n\x07product\x18\x0f \x01(\t\x12\x10\n\x08quantity\x18\x10 \x01(\x01\x12\x19\n\x11total_order_value\x18\x11 \x01(\x01\x12\x16\n\x0eretained_order\x18\x12 \x01(\x08\x12\x18\n\x10sent_to_exchange\x18\x13 \x01(\x08\x1a\x84\x04\n\x10\x43heckingResponse\x12\x17\n\x0f\x63onfirmation_id\x18\x01 \x01(\t\x12\x16\n\x0e\x66ree_space_new\x18\x02 \x01(\x01\x12\x35\n\x11response_datetime\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x31\n\x10transaction_fees\x18\x04 \x03(\x0b\x32\x17.google.protobuf.Struct\x12:\n\x19transaction_opposite_fees\x18\x05 \x03(\x0b\x32\x17.google.protobuf.Struct\x12\x32\n\x11transaction_taxes\x18\x06 \x03(\x0b\x32\x17.google.protobuf.Struct\x12?\n\x1etransaction_auto_fx_surcharges\x18\x07 \x03(\x0b\x32\x17.google.protobuf.Struct\x12H\n\'transaction_auto_fx_opposite_surcharges\x18\x08 \x03(\x0b\x32\x17.google.protobuf.Struct\x12\x1f\n\x17\x61uto_fx_conversion_rate\x18\t \x01(\x01\x12\x17\n\x0ftransaction_fee\x18\n \x01(\x01\x12 \n\x18show_ex_ante_report_link\x18\x0b \x01(\x08\x1a_\n\x14\x43onfirmationResponse\x12\x10\n\x08order_id\x18\x01 \x01(\t\x12\x35\n\x11response_datetime\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\x1b\n\x06\x41\x63tion\x12\x07\n\x03\x42UY\x10\x00\x12\x08\n\x04SELL\x10\x01\"A\n\tOrderType\x12\t\n\x05LIMIT\x10\x00\x12\x0e\n\nSTOP_LIMIT\x10\x01\x12\n\n\x06MARKET\x10\x02\x12\r\n\tSTOP_LOSS\x10\x03\"S\n\x08TimeType\x12\r\n\tUNKNOWN_0\x10\x00\x12\x11\n\rGOOD_TILL_DAY\x10\x01\x12\r\n\tUNKNOWN_2\x10\x02\x12\x16\n\x12GOOD_TILL_CANCELED\x10\x03\"\xd9\n\n\x06Update\x12\x35\n\x11response_datetime\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x37\n\x06\x61lerts\x18\x02 \x01(\x0b\x32\'.degiro_connector.trading.Update.Alerts\x12>\n\ncash_funds\x18\x03 \x01(\x0b\x32*.degiro_connector.trading.Update.CashFunds\x12L\n\x11historical_orders\x18\x04 \x01(\x0b\x32\x31.degiro_connector.trading.Update.HistoricalOrders\x12\x37\n\x06orders\x18\x05 \x01(\x0b\x32\'.degiro_connector.trading.Update.Orders\x12=\n\tportfolio\x18\x06 \x01(\x0b\x32*.degiro_connector.trading.Update.Portfolio\x12H\n\x0ftotal_portfolio\x18\x07 \x01(\x0b\x32/.degiro_connector.trading.Update.TotalPortfolio\x12\x43\n\x0ctransactions\x18\x08 \x01(\x0b\x32-.degiro_connector.trading.Update.Transactions\x1aX\n\x07Request\x12\x37\n\x06option\x18\x01 \x01(\x0e\x32\'.degiro_connector.trading.Update.Option\x12\x14\n\x0clast_updated\x18\x02 \x01(\x05\x1aG\n\x0bRequestList\x12\x38\n\x06values\x18\x01 \x03(\x0b\x32(.degiro_connector.trading.Update.Request\x1aG\n\x06\x41lerts\x12\x14\n\x0clast_updated\x18\x01 \x01(\x05\x12\'\n\x06values\x18\x02 \x01(\x0b\x32\x17.google.protobuf.Struct\x1aJ\n\tCashFunds\x12\x14\n\x0clast_updated\x18\x01 \x01(\x05\x12\'\n\x06values\x18\x02 \x01(\x0b\x32\x17.google.protobuf.Struct\x1aY\n\x10HistoricalOrders\x12\x14\n\x0clast_updated\x18\x01 \x01(\x05\x12/\n\x06values\x18\x02 \x03(\x0b\x32\x1f.degiro_connector.trading.Order\x1aO\n\x06Orders\x12\x14\n\x0clast_updated\x18\x01 \x01(\x05\x12/\n\x06values\x18\x02 \x03(\x0b\x32\x1f.degiro_connector.trading.Order\x1aJ\n\tPortfolio\x12\x14\n\x0clast_updated\x18\x01 \x01(\x05\x12\'\n\x06values\x18\x02 \x03(\x0b\x32\x17.google.protobuf.Struct\x1aO\n\x0eTotalPortfolio\x12\x14\n\x0clast_updated\x18\x01 \x01(\x05\x12\'\n\x06values\x18\x02 \x01(\x0b\x32\x17.google.protobuf.Struct\x1aM\n\x0cTransactions\x12\x14\n\x0clast_updated\x18\x01 \x01(\x05\x12\'\n\x06values\x18\x02 \x03(\x0b\x32\x17.google.protobuf.Struct\"z\n\x06Option\x12\n\n\x06\x41LERTS\x10\x00\x12\r\n\tCASHFUNDS\x10\x01\x12\x14\n\x10HISTORICALORDERS\x10\x02\x12\n\n\x06ORDERS\x10\x03\x12\r\n\tPORTFOLIO\x10\x04\x12\x12\n\x0eTOTALPORTFOLIO\x10\x05\x12\x10\n\x0cTRANSACTIONS\x10\x06\"\xbd\x02\n\rOrdersHistory\x12\'\n\x06values\x18\x01 \x03(\x0b\x32\x17.google.protobuf.Struct\x12\x35\n\x11response_datetime\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x1a\xcb\x01\n\x07Request\x12G\n\tfrom_date\x18\x01 \x01(\x0b\x32\x34.degiro_connector.trading.OrdersHistory.Request.Date\x12\x45\n\x07to_date\x18\x02 \x01(\x0b\x32\x34.degiro_connector.trading.OrdersHistory.Request.Date\x1a\x30\n\x04\x44\x61te\x12\x0c\n\x04year\x18\x01 \x01(\x05\x12\r\n\x05month\x18\x02 \x01(\x05\x12\x0b\n\x03\x64\x61y\x18\x03 \x01(\x05\"\xf4\x02\n\x13TransactionsHistory\x12\'\n\x06values\x18\x01 \x03(\x0b\x32\x17.google.protobuf.Struct\x12\x35\n\x11response_datetime\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x1a\xfc\x01\n\x07Request\x12M\n\tfrom_date\x18\x01 \x01(\x0b\x32:.degiro_connector.trading.TransactionsHistory.Request.Date\x12K\n\x07to_date\x18\x02 \x01(\x0b\x32:.degiro_connector.trading.TransactionsHistory.Request.Date\x12#\n\x1bgroup_transactions_by_order\x18\x03 \x01(\x08\x1a\x30\n\x04\x44\x61te\x12\x0c\n\x04year\x18\x01 \x01(\x05\x12\r\n\x05month\x18\x02 \x01(\x05\x12\x0b\n\x03\x64\x61y\x18\x03 \x01(\x05\"\xc3\x02\n\x0f\x41\x63\x63ountOverview\x12\'\n\x06values\x18\x01 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x35\n\x11response_datetime\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x1a\xcf\x01\n\x07Request\x12I\n\tfrom_date\x18\x01 \x01(\x0b\x32\x36.degiro_connector.trading.AccountOverview.Request.Date\x12G\n\x07to_date\x18\x02 \x01(\x0b\x32\x36.degiro_connector.trading.AccountOverview.Request.Date\x1a\x30\n\x04\x44\x61te\x12\x0c\n\x04year\x18\x01 \x01(\x05\x12\r\n\x05month\x18\x02 \x01(\x05\x12\x0b\n\x03\x64\x61y\x18\x03 \x01(\x05\"\xc5\x0e\n\rProductSearch\x12\x0e\n\x06offset\x18\x01 \x01(\x05\x12)\n\x08products\x18\x02 \x03(\x0b\x32\x17.google.protobuf.Struct\x12\x35\n\x11response_datetime\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\r\n\x05total\x18\x04 \x01(\x05\x1a\x31\n\x06\x43onfig\x12\'\n\x06values\x18\x01 \x01(\x0b\x32\x17.google.protobuf.Struct\x1a\xba\x01\n\x0cRequestBonds\x12\x1b\n\x13\x62ond_issuer_type_id\x18\x01 \x01(\x05\x12\x18\n\x10\x62ond_exchange_id\x18\x02 \x01(\x05\x12\x13\n\x0bsearch_text\x18\x03 \x01(\t\x12\x0e\n\x06offset\x18\x04 \x01(\x05\x12\r\n\x05limit\x18\x05 \x01(\x05\x12\x15\n\rrequire_total\x18\x06 \x01(\x08\x12\x14\n\x0csort_columns\x18\x07 \x01(\t\x12\x12\n\nsort_types\x18\x08 \x01(\t\x1a\xd7\x01\n\x0bRequestETFs\x12\x14\n\x0cpopular_only\x18\x01 \x01(\x08\x12\x1d\n\x15input_aggregate_types\x18\x02 \x01(\t\x12\x1e\n\x16input_aggregate_values\x18\x03 \x01(\t\x12\x13\n\x0bsearch_text\x18\x04 \x01(\t\x12\x0e\n\x06offset\x18\x05 \x01(\x05\x12\r\n\x05limit\x18\x06 \x01(\x05\x12\x15\n\rrequire_total\x18\x07 \x01(\x08\x12\x14\n\x0csort_columns\x18\x08 \x01(\t\x12\x12\n\nsort_types\x18\t \x01(\t\x1a\x83\x01\n\x0cRequestFunds\x12\x13\n\x0bsearch_text\x18\x01 \x01(\t\x12\x0e\n\x06offset\x18\x02 \x01(\x05\x12\r\n\x05limit\x18\x03 \x01(\x05\x12\x15\n\rrequire_total\x18\x04 \x01(\x08\x12\x14\n\x0csort_columns\x18\x05 \x01(\t\x12\x12\n\nsort_types\x18\x06 \x01(\t\x1a\xba\x01\n\x0eRequestFutures\x12\x1a\n\x12\x66uture_exchange_id\x18\x01 \x01(\x05\x12\x17\n\x0funderlying_isin\x18\x02 \x01(\t\x12\x13\n\x0bsearch_text\x18\x03 \x01(\t\x12\x0e\n\x06offset\x18\x04 \x01(\x05\x12\r\n\x05limit\x18\x05 \x01(\x05\x12\x15\n\rrequire_total\x18\x06 \x01(\x08\x12\x14\n\x0csort_columns\x18\x07 \x01(\t\x12\x12\n\nsort_types\x18\x08 \x01(\t\x1a\xdd\x01\n\x11RequestLeverageds\x12\x14\n\x0cpopular_only\x18\x01 \x01(\x08\x12\x1d\n\x15input_aggregate_types\x18\x02 \x01(\t\x12\x1e\n\x16input_aggregate_values\x18\x03 \x01(\t\x12\x13\n\x0bsearch_text\x18\x04 \x01(\t\x12\x0e\n\x06offset\x18\x05 \x01(\x05\x12\r\n\x05limit\x18\x06 \x01(\x05\x12\x15\n\rrequire_total\x18\x07 \x01(\x08\x12\x14\n\x0csort_columns\x18\x08 \x01(\t\x12\x12\n\nsort_types\x18\t \x01(\t\x1a\\\n\rRequestLookup\x12\x13\n\x0bsearch_text\x18\x01 \x01(\t\x12\r\n\x05limit\x18\x02 \x01(\x05\x12\x0e\n\x06offset\x18\x03 \x01(\x05\x12\x17\n\x0fproduct_type_id\x18\x04 \x01(\x05\x1a\xf9\x01\n\x0eRequestOptions\x12\x1d\n\x15input_aggregate_types\x18\x01 \x01(\t\x12\x1e\n\x16input_aggregate_values\x18\x02 \x01(\t\x12\x1a\n\x12option_exchange_id\x18\x03 \x01(\x05\x12\x17\n\x0funderlying_isin\x18\x04 \x01(\t\x12\x13\n\x0bsearch_text\x18\x05 \x01(\t\x12\x0e\n\x06offset\x18\x06 \x01(\x05\x12\r\n\x05limit\x18\x07 \x01(\x05\x12\x15\n\rrequire_total\x18\x08 \x01(\x08\x12\x14\n\x0csort_columns\x18\t \x01(\t\x12\x12\n\nsort_types\x18\n \x01(\t\x1a\xe2\x01\n\rRequestStocks\x12\x1b\n\x13is_in_us_green_list\x18\x01 \x01(\x08\x12\x10\n\x08index_id\x18\x02 \x01(\x05\x12\x13\n\x0b\x65xchange_id\x18\x03 \x01(\x05\x12\x18\n\x10stock_country_id\x18\x04 \x01(\x05\x12\x13\n\x0bsearch_text\x18\x05 \x01(\t\x12\x0e\n\x06offset\x18\x06 \x01(\x05\x12\r\n\x05limit\x18\x07 \x01(\x05\x12\x15\n\rrequire_total\x18\x08 \x01(\x08\x12\x14\n\x0csort_columns\x18\t \x01(\t\x12\x12\n\nsort_types\x18\n \x01(\t\x1a\x86\x01\n\x0fRequestWarrants\x12\x13\n\x0bsearch_text\x18\x01 \x01(\t\x12\x0e\n\x06offset\x18\x02 \x01(\x05\x12\r\n\x05limit\x18\x03 \x01(\x05\x12\x15\n\rrequire_total\x18\x04 \x01(\x08\x12\x14\n\x0csort_columns\x18\x05 \x01(\t\x12\x12\n\nsort_types\x18\x06 \x01(\t\"\xc9\x01\n\nFavourites\x12\x39\n\x06values\x18\x01 \x03(\x0b\x32).degiro_connector.trading.Favourites.List\x12\x35\n\x11response_datetime\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x1aI\n\x04List\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x12\n\nis_default\x18\x03 \x01(\x08\x12\x13\n\x0bproduct_ids\x18\x04 \x03(\x05\"T\n\x0cProductsInfo\x12\'\n\x06values\x18\x01 \x01(\x0b\x32\x17.google.protobuf.Struct\x1a\x1b\n\x07Request\x12\x10\n\x08products\x18\x01 \x03(\x05\"8\n\rCompanyRatios\x12\'\n\x06values\x18\x01 \x01(\x0b\x32\x17.google.protobuf.Struct\"9\n\x0e\x43ompanyProfile\x12\'\n\x06values\x18\x01 \x01(\x0b\x32\x17.google.protobuf.Struct\">\n\x13\x46inancialStatements\x12\'\n\x06values\x18\x01 \x01(\x0b\x32\x17.google.protobuf.Struct\"\x90\x01\n\nLatestNews\x12&\n\x05items\x18\x01 \x03(\x0b\x32\x17.google.protobuf.Struct\x12\x0e\n\x06offset\x18\x02 \x01(\x05\x12\r\n\x05total\x18\x03 \x01(\x05\x1a;\n\x07Request\x12\x0e\n\x06offset\x18\x01 \x01(\x05\x12\x11\n\tlanguages\x18\x02 \x01(\t\x12\r\n\x05limit\x18\x03 \x01(\x05\"W\n\x0eTopNewsPreview\x12&\n\x05items\x18\x01 \x03(\x0b\x32\x17.google.protobuf.Struct\x12\x0e\n\x06offset\x18\x02 \x01(\x05\x12\r\n\x05total\x18\x03 \x01(\x05\"\xa1\x01\n\rNewsByCompany\x12&\n\x05items\x18\x01 \x03(\x0b\x32\x17.google.protobuf.Struct\x12\x0e\n\x06offset\x18\x02 \x01(\x05\x12\r\n\x05total\x18\x03 \x01(\x05\x1aI\n\x07Request\x12\x0c\n\x04isin\x18\x01 \x01(\t\x12\r\n\x05limit\x18\x02 \x01(\x05\x12\x0e\n\x06offset\x18\x03 \x01(\x05\x12\x11\n\tlanguages\x18\x04 \x01(\t\"\x87\x04\n\x11\x43\x61shAccountReport\x12\x0f\n\x07\x63ontent\x18\x01 \x01(\t\x12\x42\n\x06\x66ormat\x18\x02 \x01(\x0e\x32\x32.degiro_connector.trading.CashAccountReport.Format\x12\x35\n\x11response_datetime\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x1a\xb6\x02\n\x07Request\x12\x42\n\x06\x66ormat\x18\x01 \x01(\x0e\x32\x32.degiro_connector.trading.CashAccountReport.Format\x12\x0f\n\x07\x63ountry\x18\x02 \x01(\t\x12\x0c\n\x04lang\x18\x03 \x01(\t\x12K\n\tfrom_date\x18\x04 \x01(\x0b\x32\x38.degiro_connector.trading.CashAccountReport.Request.Date\x12I\n\x07to_date\x18\x05 \x01(\x0b\x32\x38.degiro_connector.trading.CashAccountReport.Request.Date\x1a\x30\n\x04\x44\x61te\x12\x0c\n\x04year\x18\x01 \x01(\x05\x12\r\n\x05month\x18\x02 \x01(\x05\x12\x0b\n\x03\x64\x61y\x18\x03 \x01(\x05\"-\n\x06\x46ormat\x12\x07\n\x03\x43SV\x10\x00\x12\x08\n\x04HTML\x10\x01\x12\x07\n\x03PDF\x10\x02\x12\x07\n\x03XLS\x10\x03\"\x95\x05\n\x06\x41genda\x12\x44\n\rcalendar_type\x18\x01 \x01(\x0e\x32-.degiro_connector.trading.Agenda.CalendarType\x12&\n\x05items\x18\x02 \x03(\x0b\x32\x17.google.protobuf.Struct\x12\x0e\n\x06offset\x18\x03 \x01(\x05\x12\r\n\x05total\x18\x04 \x01(\x05\x12\x35\n\x11response_datetime\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x1a\xb4\x02\n\x07Request\x12\x44\n\rcalendar_type\x18\x01 \x01(\x0e\x32-.degiro_connector.trading.Agenda.CalendarType\x12\x0e\n\x06offset\x18\x02 \x01(\x05\x12\r\n\x05limit\x18\x03 \x01(\x05\x12\x15\n\rorder_by_desc\x18\x04 \x01(\x08\x12.\n\nstart_date\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12,\n\x08\x65nd_date\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x14\n\x0c\x63ompany_name\x18\x07 \x01(\t\x12\x11\n\tcountries\x18\x08 \x01(\t\x12\x17\n\x0f\x63lassifications\x18\t \x01(\t\x12\r\n\x05units\x18\n \x01(\t\"\x8f\x01\n\x0c\x43\x61lendarType\x12\x15\n\x11\x44IVIDEND_CALENDAR\x10\x00\x12\x15\n\x11\x45\x43ONOMIC_CALENDAR\x10\x01\x12\x15\n\x11\x45\x41RNINGS_CALENDAR\x10\x02\x12\x14\n\x10HOLIDAY_CALENDAR\x10\x03\x12\x10\n\x0cIPO_CALENDAR\x10\x04\x12\x12\n\x0eSPLIT_CALENDAR\x10\x05\"\xcc\x01\n\x12\x45stimatesSummaries\x12\'\n\x06\x61nnual\x18\x01 \x03(\x0b\x32\x17.google.protobuf.Struct\x12\x10\n\x08\x63urrency\x18\x02 \x01(\t\x12(\n\x07interim\x18\x03 \x03(\x0b\x32\x17.google.protobuf.Struct\x12\x15\n\rlastRetrieved\x18\x04 \x01(\t\x12\x13\n\x0blastUpdated\x18\x05 \x01(\t\x12\x18\n\x10preferredMeasure\x18\x06 \x01(\t\x12\x0b\n\x03ric\x18\x07 \x01(\t\"\xae\x03\n\x0ePositionReport\x12\x0f\n\x07\x63ontent\x18\x01 \x01(\t\x12?\n\x06\x66ormat\x18\x02 \x01(\x0e\x32/.degiro_connector.trading.PositionReport.Format\x12\x35\n\x11response_datetime\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x1a\xe3\x01\n\x07Request\x12?\n\x06\x66ormat\x18\x01 \x01(\x0e\x32/.degiro_connector.trading.PositionReport.Format\x12\x0f\n\x07\x63ountry\x18\x02 \x01(\t\x12\x0c\n\x04lang\x18\x03 \x01(\t\x12\x46\n\x07to_date\x18\x05 \x01(\x0b\x32\x35.degiro_connector.trading.PositionReport.Request.Date\x1a\x30\n\x04\x44\x61te\x12\x0c\n\x04year\x18\x01 \x01(\x05\x12\r\n\x05month\x18\x02 \x01(\x05\x12\x0b\n\x03\x64\x61y\x18\x03 \x01(\x05\"-\n\x06\x46ormat\x12\x07\n\x03\x43SV\x10\x00\x12\x08\n\x04HTML\x10\x01\x12\x07\n\x03PDF\x10\x02\x12\x07\n\x03XLS\x10\x03\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'degiro_connector.trading.models.trading_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _CREDENTIALS._serialized_start=139
  _CREDENTIALS._serialized_end=278
  _ORDER._serialized_start=281
  _ORDER._serialized_end=1581
  _ORDER_CHECKINGRESPONSE._serialized_start=787
  _ORDER_CHECKINGRESPONSE._serialized_end=1303
  _ORDER_CONFIRMATIONRESPONSE._serialized_start=1305
  _ORDER_CONFIRMATIONRESPONSE._serialized_end=1400
  _ORDER_ACTION._serialized_start=1402
  _ORDER_ACTION._serialized_end=1429
  _ORDER_ORDERTYPE._serialized_start=1431
  _ORDER_ORDERTYPE._serialized_end=1496
  _ORDER_TIMETYPE._serialized_start=1498
  _ORDER_TIMETYPE._serialized_end=1581
  _UPDATE._serialized_start=1584
  _UPDATE._serialized_end=2953
  _UPDATE_REQUEST._serialized_start=2111
  _UPDATE_REQUEST._serialized_end=2199
  _UPDATE_REQUESTLIST._serialized_start=2201
  _UPDATE_REQUESTLIST._serialized_end=2272
  _UPDATE_ALERTS._serialized_start=2274
  _UPDATE_ALERTS._serialized_end=2345
  _UPDATE_CASHFUNDS._serialized_start=2347
  _UPDATE_CASHFUNDS._serialized_end=2421
  _UPDATE_HISTORICALORDERS._serialized_start=2423
  _UPDATE_HISTORICALORDERS._serialized_end=2512
  _UPDATE_ORDERS._serialized_start=2514
  _UPDATE_ORDERS._serialized_end=2593
  _UPDATE_PORTFOLIO._serialized_start=2595
  _UPDATE_PORTFOLIO._serialized_end=2669
  _UPDATE_TOTALPORTFOLIO._serialized_start=2671
  _UPDATE_TOTALPORTFOLIO._serialized_end=2750
  _UPDATE_TRANSACTIONS._serialized_start=2752
  _UPDATE_TRANSACTIONS._serialized_end=2829
  _UPDATE_OPTION._serialized_start=2831
  _UPDATE_OPTION._serialized_end=2953
  _ORDERSHISTORY._serialized_start=2956
  _ORDERSHISTORY._serialized_end=3273
  _ORDERSHISTORY_REQUEST._serialized_start=3070
  _ORDERSHISTORY_REQUEST._serialized_end=3273
  _ORDERSHISTORY_REQUEST_DATE._serialized_start=3225
  _ORDERSHISTORY_REQUEST_DATE._serialized_end=3273
  _TRANSACTIONSHISTORY._serialized_start=3276
  _TRANSACTIONSHISTORY._serialized_end=3648
  _TRANSACTIONSHISTORY_REQUEST._serialized_start=3396
  _TRANSACTIONSHISTORY_REQUEST._serialized_end=3648
  _TRANSACTIONSHISTORY_REQUEST_DATE._serialized_start=3225
  _TRANSACTIONSHISTORY_REQUEST_DATE._serialized_end=3273
  _ACCOUNTOVERVIEW._serialized_start=3651
  _ACCOUNTOVERVIEW._serialized_end=3974
  _ACCOUNTOVERVIEW_REQUEST._serialized_start=3767
  _ACCOUNTOVERVIEW_REQUEST._serialized_end=3974
  _ACCOUNTOVERVIEW_REQUEST_DATE._serialized_start=3225
  _ACCOUNTOVERVIEW_REQUEST_DATE._serialized_end=3273
  _PRODUCTSEARCH._serialized_start=3977
  _PRODUCTSEARCH._serialized_end=5838
  _PRODUCTSEARCH_CONFIG._serialized_start=4123
  _PRODUCTSEARCH_CONFIG._serialized_end=4172
  _PRODUCTSEARCH_REQUESTBONDS._serialized_start=4175
  _PRODUCTSEARCH_REQUESTBONDS._serialized_end=4361
  _PRODUCTSEARCH_REQUESTETFS._serialized_start=4364
  _PRODUCTSEARCH_REQUESTETFS._serialized_end=4579
  _PRODUCTSEARCH_REQUESTFUNDS._serialized_start=4582
  _PRODUCTSEARCH_REQUESTFUNDS._serialized_end=4713
  _PRODUCTSEARCH_REQUESTFUTURES._serialized_start=4716
  _PRODUCTSEARCH_REQUESTFUTURES._serialized_end=4902
  _PRODUCTSEARCH_REQUESTLEVERAGEDS._serialized_start=4905
  _PRODUCTSEARCH_REQUESTLEVERAGEDS._serialized_end=5126
  _PRODUCTSEARCH_REQUESTLOOKUP._serialized_start=5128
  _PRODUCTSEARCH_REQUESTLOOKUP._serialized_end=5220
  _PRODUCTSEARCH_REQUESTOPTIONS._serialized_start=5223
  _PRODUCTSEARCH_REQUESTOPTIONS._serialized_end=5472
  _PRODUCTSEARCH_REQUESTSTOCKS._serialized_start=5475
  _PRODUCTSEARCH_REQUESTSTOCKS._serialized_end=5701
  _PRODUCTSEARCH_REQUESTWARRANTS._serialized_start=5704
  _PRODUCTSEARCH_REQUESTWARRANTS._serialized_end=5838
  _FAVOURITES._serialized_start=5841
  _FAVOURITES._serialized_end=6042
  _FAVOURITES_LIST._serialized_start=5969
  _FAVOURITES_LIST._serialized_end=6042
  _PRODUCTSINFO._serialized_start=6044
  _PRODUCTSINFO._serialized_end=6128
  _PRODUCTSINFO_REQUEST._serialized_start=6101
  _PRODUCTSINFO_REQUEST._serialized_end=6128
  _COMPANYRATIOS._serialized_start=6130
  _COMPANYRATIOS._serialized_end=6186
  _COMPANYPROFILE._serialized_start=6188
  _COMPANYPROFILE._serialized_end=6245
  _FINANCIALSTATEMENTS._serialized_start=6247
  _FINANCIALSTATEMENTS._serialized_end=6309
  _LATESTNEWS._serialized_start=6312
  _LATESTNEWS._serialized_end=6456
  _LATESTNEWS_REQUEST._serialized_start=6397
  _LATESTNEWS_REQUEST._serialized_end=6456
  _TOPNEWSPREVIEW._serialized_start=6458
  _TOPNEWSPREVIEW._serialized_end=6545
  _NEWSBYCOMPANY._serialized_start=6548
  _NEWSBYCOMPANY._serialized_end=6709
  _NEWSBYCOMPANY_REQUEST._serialized_start=6636
  _NEWSBYCOMPANY_REQUEST._serialized_end=6709
  _CASHACCOUNTREPORT._serialized_start=6712
  _CASHACCOUNTREPORT._serialized_end=7231
  _CASHACCOUNTREPORT_REQUEST._serialized_start=6874
  _CASHACCOUNTREPORT_REQUEST._serialized_end=7184
  _CASHACCOUNTREPORT_REQUEST_DATE._serialized_start=3225
  _CASHACCOUNTREPORT_REQUEST_DATE._serialized_end=3273
  _CASHACCOUNTREPORT_FORMAT._serialized_start=7186
  _CASHACCOUNTREPORT_FORMAT._serialized_end=7231
  _AGENDA._serialized_start=7234
  _AGENDA._serialized_end=7895
  _AGENDA_REQUEST._serialized_start=7441
  _AGENDA_REQUEST._serialized_end=7749
  _AGENDA_CALENDARTYPE._serialized_start=7752
  _AGENDA_CALENDARTYPE._serialized_end=7895
  _ESTIMATESSUMMARIES._serialized_start=7898
  _ESTIMATESSUMMARIES._serialized_end=8102
  _POSITIONREPORT._serialized_start=8105
  _POSITIONREPORT._serialized_end=8535
  _POSITIONREPORT_REQUEST._serialized_start=8261
  _POSITIONREPORT_REQUEST._serialized_end=8488
  _POSITIONREPORT_REQUEST_DATE._serialized_start=3225
  _POSITIONREPORT_REQUEST_DATE._serialized_end=3273
  _POSITIONREPORT_FORMAT._serialized_start=7186
  _POSITIONREPORT_FORMAT._serialized_end=7231
# @@protoc_insertion_point(module_scope)
